Intended for user download where udpipe fails to download automatically.
Arguments
- model
A string naming a UDPipe model. See
udpipe::udpipe_download_model()for the list of available models.
Intended for user download where udpipe fails to download automatically.
A string naming a UDPipe model. See udpipe::udpipe_download_model() for the list of available models.