Skip to contents

Parse a data frame into a redaction function with optional caching.

Usage

parse_redacter(redacter, with_cache = TRUE)

Arguments

redacter

A data.frame containing From, To and If or a file path to

with_cache

A binary flag to control if memoization is required.