Skip to contents

Add a reader function for a specific file extension.

Usage

register_reader(fun, ext)

Arguments

fun

The function to read files with the specified extension. The function should take a file path as its first argument and return a data frame.

ext

The file extension (e.g., "csv", "txt").

Examples

# example code