Reinstate the default read functionality for csv, tsv, xls, and xlsx files.
Source:R/register_reader.R
reinstate_default_reader.RdReinstate the default read functionality for csv, tsv, xls, and xlsx files.

R/register_reader.R
reinstate_default_reader.RdReinstate the default read functionality for csv, tsv, xls, and xlsx files.