Skip to contents

Convert the output of pidpos to a tibble or csv file for editing. It is intended the user changes the To column to define desired redactions.

Usage

report_to_redaction_rules(report, path = NULL, include_context = FALSE)

Arguments

report

The data.frame generated by pidpos

path

Optional file path to write to.

include_context

Binary-flag. If True, adds a Context column giving a subset of the sentence being redacted around the token.

Value

A tibble with columns:

  • If: The condition (sentence) under which the replacement is to be made.

  • From: The original token.

  • To: The replacement token.

See also

Examples

if (FALSE) { # \dontrun{
example.data <- head(the_one_in_massapequa)
report <- pidpos(example.data, to_remove = "speaker")
report_to_redaction_rules(report)
} # }