A short data frame of free text including PID. Used for basic examples and tests.
Source:R/data.R
sentence_frm.RdA short data frame of free text including PID. Used for basic examples and tests.

R/data.R
sentence_frm.RdA short data frame of free text including PID. Used for basic examples and tests.