Skip to contents

For use as part of the folder level API - this function is the equivalent of get_distinct_redaction_rules().

Usage

get_distinct_redaction_rules(object, include_context = FALSE)

Arguments

object

The object to extract distinct redaction rules from. Can be a path to a folder of pid reports, a list of pid reports, or a single data frame.

include_context

A boolean flag indicating whether to include context information in the output. Default is FALSE.