Combine multiple PID reports into a single rule set
Source:R/get_distinct_redaction_rules.R
get_distinct_redaction_rules.RdFor use as part of the folder level API - this function is the equivalent of
get_distinct_redaction_rules().

R/get_distinct_redaction_rules.R
get_distinct_redaction_rules.RdFor use as part of the folder level API - this function is the equivalent of
get_distinct_redaction_rules().