Convert the output of pidpos to a tibble or csv file for editing.
It is intended the user changes the To column to define desired
redactions.
Value
A tibble with columns:
If: The condition (sentence) under which the replacement is to be made.From: The original token.To: The replacement token.
See also
To produce the report:
pidpos()To automatically replace the
Tocolumn:auto_replace()For redaction:
redact()