Summarize a pidpos report.
Usage
# S3 method for class 'pidpos'
summary(object, ...)Value
A data frame describing any column determined to contain PID.
Column
Cases of Proper Nouns - the number of sentences with proper nouns in the column
Unique Cases of Proper Nouns - the number of unique sentences with proper nouns in the column
Most Common Proper Noun Sentence - the most commonly occurring sentence containing proper nouns.